# FileShareServiceStatsGroup

An array that contains a group of stats pertaining to a FileShareService.  A group of stats would comprise a list of FileShareServiceStats stats managed by an entity, such as an AgentConnector. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


